@@ -19,7 +19,7 @@
  * @package  Date_Holidays
  * @author   Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Japan.php,v 1.5 2009/01/19 21:54:21 kguest Exp $
+ * @version  CVS: $Id: Japan.php 277166 2009-03-14 21:31:51Z kguest $
  * @link     http://pear.php.net/package/Date_Holidays
  * @see      http://www.h3.dion.ne.jp/~sakatsu/holiday_topic.htm
  */
@@ -93,12 +93,20 @@ define('DATE_HOLIDAYS_AUTUMNAL_EQUINOX_PARAM_2150', 24.2488);
  * @subpackage Driver
  * @author     Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license    http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version    CVS: $Id: Japan.php,v 1.5 2009/01/19 21:54:21 kguest Exp $
+ * @version    CVS: $Id: Japan.php 277166 2009-03-14 21:31:51Z kguest $
  * @link       http://pear.php.net/package/Date_Holidays
  * @see        http://www.h3.dion.ne.jp/~sakatsu/holiday_topic.htm
  */
 class Date_Holidays_Driver_Japan extends Date_Holidays_Driver
 {
+    /**
+     * this driver's name
+     *
+     * @access   protected
+     * @var      string
+     */
+    var $_driverName = 'Japan';
+
     /**
      * a translation file name
      *
