@@ -9,7 +9,7 @@
  * @package  Date_Holidays
  * @author   Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_Japan_TestSuite.php,v 1.4 2008/09/06 12:17:57 shimooka Exp $
+ * @version  CVS: $Id: Date_Holidays_Driver_Japan_TestSuite.php 282411 2009-06-19 02:02:06Z shimooka $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 if (!defined("PHPUnit_MAIN_METHOD")) {
@@ -29,7 +29,7 @@ define('LANG_FILE', '/usr/local/lib/php5/pear/data/Date_Holidays_Japan/lang/');
  * @package  Date_Holidays
  * @author   Hideyuki Shimooka <shimooka@doyouphp.jp>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_Japan_TestSuite.php,v 1.4 2008/09/06 12:17:57 shimooka Exp $
+ * @version  CVS: $Id: Date_Holidays_Driver_Japan_TestSuite.php 282411 2009-06-19 02:02:06Z shimooka $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
@@ -1582,6 +1582,32 @@ class Date_Holidays_Driver_Japan_TestSuite extends PHPUnit_Framework_TestCase
         $this->assertEquals('みどりの日', $obj->getHolidayForDate('2007-05-04', 'ja_JP')->getTitle(), 'showa day in 2007');
     }
 
+    /**
+     * bug #16338
+     *
+     * @access public
+     * @return void
+     */
+    function test16338()
+    {
+        for ($year = 1900; $year < date('Y'); $year++) {
+            $obj = Date_Holidays::factory('Japan', $year, 'ja_JP');
+            if (Date_Holidays::isError($obj)) {
+                $this->fail('Factory was unable to produce driver-object');
+            }
+            $obj->addTranslationFile(LANG_FILE . '/Japan/ja_JP.xml', 'ja_JP');
+            if (Date_Holidays::isError($obj)) {
+                $this->fail('fail to add translation file');
+            }
+            $holidays = array();
+            foreach ($obj->getHolidays() as $h) {
+                if (PEAR::isError($h)) {
+                    $this->fail('test failed');
+                }
+                $holidays[$h->getDate()->format('%Y-%m-%d')] = $h->getTitle();
+            }
+        }
+    }
 }
 
 ?>
